<?php
class cmsWysiwygCkeditor {

    private static $editor_loaded = false;

    private $options = [
        'language' => 'en'
    ];

    public function __construct($config = []) {
        $this->options = array_replace_recursive($this->options, $config);

        $user = cmsUser::getInstance();
        $core = cmsCore::getInstance();
        $lang = cmsCore::getLanguageName();

        if($lang !== 'en'){
            $this->options['language'] = $lang;
        }
        
        if ($user->is_logged) {

            $context = $core->getUriData();
            $upload_params = [];

            if($context['controller']){
                $upload_params['target_controller'] = $context['controller'];
            }

            if($context['action']){
                $upload_params['target_subject'] = $context['action'];
            }

            if(strpos($core->uri, '/add/') === false && !empty($context['params'][1]) && is_numeric($context['params'][1])){
                $upload_params['target_id'] = $context['params'][1];
            }
            
            //Store image in original size only. See actionImagesUpload->run
            $upload_params['sizes'] = 'original';

            $upload_params_string = ($upload_params ? '?'.http_build_query($upload_params) : '');

            $this->options['uploadUrl'] = href_to('images', 'upload', ['upload']).$upload_params_string;
        }

        $this->options = array_replace_recursive($this->options, $config);
    }

    public function displayEditor($field_id, $content = '', $config = []) {

        $this->loadEditor();

        $dom_id = str_replace(array('[',']'), array('_', ''), $field_id);

        if($dom_id){
            echo html_textarea($field_id, $content, array('id' => $dom_id, 'class' => 'ckeditor_editor'));
        }

        ob_start(); ?>
        
        <?php if(self::$editor_loaded){ ?>
            <script type="text/javascript">
                <?php if($dom_id){ ?>
                    ckeditor_global_options['field_<?php echo $dom_id; ?>'] = <?php echo json_encode($this->options); ?>;
                    $(function(){
                        init_ckeditor('<?php echo $dom_id; ?>');
                    });
                <?php } else { ?>
                    ckeditor_global_options['default'] = <?php echo json_encode($this->options); ?>;
                <?php } ?>
            </script>
        <?php } ?>
        
        <?php cmsTemplate::getInstance()->addBottom(ob_get_clean());
    }

    private function loadEditor() {
        if(self::$editor_loaded){
            return false; 
        }

        $path='';
        $user = cmsUser::getInstance();
        if ($user->is_admin) {
            $path=$this->options['admin_editor'];
        } else if ($user->isInGroup(5)) { //Moderator
            $path=$this->options['moderator_editor'];
        } else if ($user->is_logged) {
            $path=$this->options['logged_editor'];
        }
        else {
            $path=$this->options['all_editor'];
        }
        
        if (empty($path) || $path=='no') {
            return false;
        }

        $template = cmsTemplate::getInstance();        
        $template->addJSFromContext('wysiwyg/ckeditor/' . $path . '/ckeditor.js');
        
        ob_start(); ?>

        <script type="text/javascript">
            var ckeditor_global_options = {};
            function init_ckeditor(dom_id) {
                var ckeditor_options = {};
                if(ckeditor_global_options.hasOwnProperty('field_'+dom_id)){
                    ckeditor_options = ckeditor_global_options['field_'+dom_id];
                } else if(tiny_global_options.hasOwnProperty('default')) {
                    ckeditor_options = ckeditor_global_options.default;
                }
                var editor = CKEDITOR.replace(dom_id
                , {
                    language: ckeditor_options.language,
                    uploadUrl: ckeditor_options.uploadUrl,
                    imageUploadUrl: ckeditor_options.uploadUrl,
                    filebrowserUploadUrl: ckeditor_options.uploadUrl
                }
                );
                
                editor.on( 'fileUploadResponse', function( evt ) {
                    // Prevent the default response handler.
                    evt.stop();
                
                    // Get XHR and response.
                    var data = evt.data;
                    var xhr = data.fileLoader.xhr;
                    var response = xhr.responseText;
                    var respJson = JSON.parse(response);
                    if (respJson.success) {
                        //data.url = respJson.location;
                        data.url = respJson.paths.original.url;
                    } else {
                        // An error occurred during upload.
                        data.message = respJson.error;
                        evt.cancel();
                    }
                });
            }
        </script>

        <?php $template->addBottom(ob_get_clean());

        self::$editor_loaded = true;
    }
}
